/// <reference types="node" />
import { ApiOptions } from '../models/ApiOptions';
import { ApiResponse } from '../models/ApiResponse';
import { Criterion } from '../models/Criterion';
import { DataFormat } from '../models/DataFormat';
export declare class JuracusClient {
    private static instances;
    private readonly restClient;
    private readonly websocketClient;
    private connectionId;
    private response;
    private resolveConnectionId?;
    private resolveApiResponse?;
    /**
     * Returns created instance of JuracusClient
     *
     * @param apiKey Key to authorize access to JuracusApi
     */
    static readonly getInstance: (apiKey: string) => JuracusClient;
    /**
     * Creates and configures RestApi and WebsocketApi client with given apiKey as authorization.
     *
     * @param apiKey Key to authorize access to JuracusApi
     */
    private constructor();
    /**
     * Analyze given data with JuracusAI
     *
     * @param criteria   {@link Collection} of criteria to analyze.
     * @param dataFormat Format of the provided file data.
     * @param data       Data of the file to analyze. Can be provided as base64 String, Blob object or Buffer. You can find the supported file types here: {@link DataFormat}.
     * @return response  Response as Promise with which you can access the Analysis response asynchronously.
     */
    readonly analyzeAsyncFromCriteria: (dataFormat: DataFormat, data: string | Blob | Buffer, criteria: readonly Criterion[]) => Promise<ApiResponse>;
    /**
     * Analyze given data with JuracusAI
     *
     * @param tasks      {@link Map} containing the criteria to analyze together with their {@link ApiOptions}.
     * @param dataFormat Format of the provided file data.
     * @param data Data of the file to analyze. Can be provided as base64 String, Blob object or Buffer. You can find the supported file types here: {@link DataFormat}.
     * @return response  Result as Promise with which you can access the Analysis response asynchronously.
     */
    readonly analyzeAsyncFullSpecification: (dataFormat: DataFormat, data: string | Blob | Buffer, tasks: Map<Criterion, ApiOptions>) => Promise<ApiResponse>;
    /**
     * Analyze given data with JuracusAI
     *
     * @param criteria       {@link Collection} of criteria to analyze.
     * @param defaultOptions {@link ApiOptions} default options to use for each analyzed criterion.
     * @param dataFormat     Format of the provided file data.
     * @param data           Data of the file to analyze. Can be provided as base64 String, Blob object or Buffer. You can find the supported file types here: {@link DataFormat}.
     * @return response  Result as Promise with which you can access the Analysis response asynchronously.
     */
    readonly analyzeAsyncFromCriteriaWithOptions: (dataFormat: DataFormat, data: string | Blob | Buffer, criteria: readonly Criterion[], defaultOptions: ApiOptions) => Promise<ApiResponse>;
    /**
     * Gets called when Websocket message is sent from the server. Executes analysis when ConnectionId is delivered,
     * and completes analysis when done
     *
     * @param event Received message from server in format {@link UpdateMessage}
     */
    private readonly handleWebsocketMessage;
    private readonly maintainWebsocketConnection;
    /**
     * Sends request to get connectionId and maintains connection by sending heartbeat request every 4 minutes
     * @param event {@link OpenEvent}
     */
    private readonly sendConnectionIdRequestOnOpen;
    /**
     * Resets response so a new request can be processed correctly
     */
    private readonly initializeResponse;
    /**
     * Resets connectionId so a new connection can be established
     */
    private readonly initializeConnectionId;
    private readonly handleOnClose;
    /**
     * Creates {@link ApiResponse} from {@link Error} and resolves the request
     * @param error AxiosError to build the response from
     */
    private readonly createApiResponseFromInternError;
    /**
     * Creates {@link ApiResponse} from {@link AxiosError} and resolves the request
     * @param error AxiosError to build the response from
     */
    private readonly createApiResponseFromAxiosError;
    /**
     * Creates {@link ApiResponse} from Conversion error message and type and resolves the request
     * @param message Conversion error message
     * @param name Conversion error name
     */
    private readonly createApiResponseFromConversionError;
}
